Opens the output directory in the system file browser (Finder on macOS, Explorer on Windows, or the default file manager on Linux). When called without arguments, tries to open the most recently exported results directory without prompting for an options file.
Arguments
- options
[character, optional] Name of the options file (with or without
.yamlextension). IfNULL, the function first checks for a recent export marker. If no marker is found and running interactively, you will be prompted to select an options file.- options_dir
[character, optional] Directory containing the options file. If
NULL, uses the default options directory.- use_last
[logical] If
TRUE(default) and nooptions/options_dirare provided, automatically open the most recently exported results directory. Set toFALSEto always resolve via the options file.