Sets specific config fields for a variable. Only non-default values are persisted to the options file.
Arguments
- var_name
[character] The variable name to configure.
- ...
Named arguments for config fields to set (e.g.,
bma = TRUE, bma_to_log = TRUE). Column mappings are set the same way:source_name = "study_name"maps the variable to that column in the data file, anddrop_conflicting_raw = TRUEkeeps such a mapping while dropping a different raw column that occupies the standard name.- options_file_name
[character, optional] The name of the options file. If
NULL(default), the user will be prompted interactively.- options_dir
[character, optional] The directory containing options files. If
NULL(default), the default directory is used.