if Statements Without BracesWraps lintr::indentation_linter() to avoid emitting indentation warnings for guard-clause
style if statements where a single, indented expression immediately follows the condition
on the next line. This keeps the rest of the indentation behavior intact while permitting the
brace-less guard clause convention adopted in the codebase.
indentation_guard_clause_linter(indent = 2L, ...)Integer number of spaces to use for indentation checks.
Additional arguments forwarded to lintr::indentation_linter().