Compares two user options files, printing the options whose values differ between them, followed by each file's deviations from the template defaults.
Usage
options_diff(
options_file_name_a = NULL,
options_file_name_b = NULL,
options_dir = NULL,
template_path = NULL
)Arguments
- options_file_name_a
[character, optional] Name of the first options file to compare. If not provided, the user will be prompted. Defaults to
NULL.- options_file_name_b
[character, optional] Name of the second options file to compare. If not provided, the user will be prompted. Defaults to
NULL.- options_dir
[character, optional] Full path to the folder that contains user options files. If not provided, the default folder is chosen. Defaults to
NULL.- template_path
[character, optional] Full path to the options template file. Defaults to
NULL.