Returns the resolved path to the output directory where analysis results (tables, graphics) are saved. The path is printed and returned invisibly. When called without arguments, tries to use the most recently exported directory without prompting for an options file.
Arguments
- options
[character, optional] Name of the options file (with or without
.yamlextension). IfNULL, the function first checks for a recent export marker. If no marker is found and running interactively, you will be prompted to select an options file.- options_dir
[character, optional] Directory containing the options file. If
NULL, uses the default options directory.